import { createApp } from 'vue';
import App from './App.vue';
import router from './router';
import axios from 'axios';
import store from '@/store/index.js';
import OrganizationView from '@/views/systemview/OrganizationView.vue';
import Role from '@/views/systemview/Role.vue';
import Menu from '@/views/systemview/Menu.vue';
import UserList from '@/views/systemview/UserList.vue';
import VncShow from '@/views/VncShow.vue';
import EmailCenter from '@/views/systemview/EmailCenter';
import TestReport from '@/views/tool/TestReport';
import Echarts from "vue-echarts";
import 'echarts';
import ECharts from 'vue-echarts';
import ViewUIPlus from 'view-ui-plus';



const app = createApp(App).use(store)
import 'view-ui-plus/dist/styles/viewuiplus.css'

axios.defaults.withCredentials = true
axios.defaults.baseURL = '/api'
// axios.defaults.baseURL = 0 ? 'http://172.22.25.173/api' : 'http://47.57.235.86:10001'
app.config.globalProperties.$http = axios
app.component('v-chart', Echarts)


const routers = [
    {
        path: 'vcnshow',
        name: 'vncshow',
        component: VncShow
    }, {
        path: 'organization',
        name: 'organization',
        component: OrganizationView
    }, {
        path: 'role',
        name: 'role',
        component: Role
    }, {
        path: 'menu',
        name: 'menu',
        component: Menu
    }, {
        path: 'userlist',
        name: 'userlist',
        component: UserList
    }, {
        path: 'report',
        name: 'report',
        component: TestReport
    }, {
        path: 'emialcenter',
        name: 'emialcenter',
        component: EmailCenter
    }
]

axios.interceptors.request.use(function (config) {
    if (store.getters.gettoken != "" && config.url != "user/login") config.headers['token'] = store.getters.gettoken
    return config;
});

// axios.interceptors.response.use(function (response) {
//     if (response.data.code != 41000) return response;
//     this.$Message.error("登录已过期")
//     store.commit("settoken", '');
//     router.push('/login')
// })


router.beforeEach(async (to, from, next) => {
    const a = (value) => {
        for (let each of value) {
            if (each.router) {
                const index_ = routers.findIndex(ele => { return ele.name == each.router })
                if (index_ != -1) { router.addRoute('home', { 'name': each.router, 'path': each.router, component: routers[index_].component }) }
            }
            if (each.children) {
                a(each.children)
            }
        }
    }
    const findMenu = (menu, each) => {
        for (let ele in menu) {
            if (ele.router == each) return true
            if (ele.children) return findMenu(ele.children, each)
        }
    }
    if (to.path == '/login') return next();
    if (localStorage.getItem('token')) {
        let userinfo = localStorage.getItem("userinfo")
        if (!userinfo) {
            var res = await axios.get("user/userdetail", 'get')
            userinfo = res.data.data
        } else {
            userinfo = JSON.parse(userinfo)
        }
        const menu = userinfo.menu
        if (findMenu(menu, to.name) && !router.hasRoute(to.name)) {
            a(menu)
            console.info(router.getRoutes())
            return next(to)
        }
        return next()
    } else {
        return next('/login')
    }
})

function request(method, url, data, apply, successFun = () => { }, failFun = () => { }) {
    axios[method](url, method != 'get' ? data : { params: data }).then(res => {
        const data = JSON.parse(JSON.stringify(res.data))
        if (method != "get" && apply) apply.$Message.success(data.message);
        successFun(res.data)
    }).catch(error => {
        console.info(error)
        try {
            if (error.response.data.code == 401) {
                apply.$Message.error(error.response.data.message);
                router.push('login')
            } else {
                apply && apply.$Message.error(error.response.data.message);
                failFun(error.response.data)
            }
        }
        catch {
            apply && apply.$Message.error("系统处理错误");
            failFun()
        }
    })
}

function getElements(page_id, apply, fun) {
    request('get', 'user/elements', { "id": page_id }, apply, fun)
}




app.config.globalProperties.$getElements = getElements

app.config.globalProperties.$request = request

app.config.globalProperties.elePro = function (menu_id) {
    return null
}

app.config.globalProperties.$routers = routers

app.provide("$http", axios);
app.provide("$request", request);
app.provide("$getElements", getElements);
app.use(ViewUIPlus).use(router).mount('#app')
